#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_version(*file_paths):
    """Retrieves the version from django_json_widget/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


# version = get_version("django_json_widget", "__init__.py")


if sys.argv[-1] == "publish":
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print("Wheel library missing. Please run \"pip install wheel\"")
        sys.exit()
    os.system("python setup.py sdist upload")
    os.system("python setup.py bdist_wheel upload")
    sys.exit()

if sys.argv[-1] == "tag":
    print("Tagging the version on git:")
    os.system("git tag -a %s -m \"version %s\"" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open("README.rst").read()
history = open("HISTORY.rst").read().replace(".. :changelog:", "")

setup(
    name="dj-json-widget",
    version="2.1.0",
    description="""Django json widget is an alternative widget that makes it easy to edit the jsonfield field of django.""",
    long_description=readme + "\n\n" + history,
    author="José Manuel Rivas, Erfan Arefmehr",
    author_email="jmrivas86@gmail.com",
    url="https://github.com/jmrivas86/django-json-widget",
    packages=[
        "django_json_widget",
    ],
    include_package_data=True,
    license="MIT",
    zip_safe=False,
    keywords="dj-json-widget",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.2",
        "Framework :: Django :: 5.0",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
)
